diff -ru orig/libapache2-mod-python-3.1.3/Doc/modpython4.tex libapache2-mod-python-3.1.3/Doc/modpython4.tex
--- orig/libapache2-mod-python-3.1.3/Doc/modpython4.tex	2004-02-05 06:22:42.000000000 -0600
+++ libapache2-mod-python-3.1.3/Doc/modpython4.tex	2004-05-31 00:41:04.000000000 -0600
@@ -2291,8 +2291,22 @@
     \end{verbatim}
   \end{methoddesc}
 
+  \begin{methoddesc}{exit}{}
+    This method causes processing of the current PSP page to terminate without
+    error.  It is analogous to the \code{sys.exit} function, except it takes
+    no arguments and does not cause the Python interpreter to exit.
+  \end{methoddesc}
+
 \end{classdesc}
 
+\begin{excclassdesc}{PSPExit}{}
+  This exception is raised by the \class{psp.exit} function, and is treated
+  as a non-error by the PSP interpreter.  When it is not handled, it will
+  cause processing of the current PSP page to stop.  As \method{psp.exit} is
+  analogous to \code{sys.exit}, \exception{PSPExit} is analogous
+  to the \exception{SystemExit}.
+\end{excclassdesc}
+
 Additionally, the \module{psp} module provides the following low level
 functions:
 
diff -ru orig/libapache2-mod-python-3.1.3/lib/python/mod_python/psp.py libapache2-mod-python-3.1.3/lib/python/mod_python/psp.py
--- orig/libapache2-mod-python-3.1.3/lib/python/mod_python/psp.py	2004-02-16 13:47:27.000000000 -0600
+++ libapache2-mod-python-3.1.3/lib/python/mod_python/psp.py	2004-05-31 00:34:49.000000000 -0600
@@ -55,6 +55,12 @@
 
     return new.code(*marshal.loads(s))
 
+class PSPExit(Exception):
+    """
+    Prematurely exit a PSP page.
+    """
+    
+
 class PSPInterface:
 
     def __init__(self, req, filename, form):
@@ -83,6 +89,10 @@
 
         util.redirect(self.req, location, permanent)
 
+    def exit(self):
+        
+        raise PSPExit
+
 class PSP:
 
     code = None
@@ -205,7 +215,10 @@
             global_scope.update(self.vars) # passed in __init__()
             global_scope.update(vars)      # passed in run()
             try:
-                exec code in global_scope
+                try:
+                    exec code in global_scope
+                except PSPExit:
+                    pass
                 req.flush()
                 
                 # the mere instantiation of a session changes it
